@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2018
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,24 +25,48 @@ class ChatPhoto(TelegramObject):
 
     Attributes:
         small_file_id (:obj:`str`): File identifier of small (160x160) chat photo.
+            This file_id can be used only for photo download and only for as long
+            as the photo is not changed.
+        small_file_unique_id (:obj:`str`): Unique file identifier of small (160x160) chat photo,
+            which is supposed to be the same over time and for different bots.
+            Can't be used to download or reuse the file.
         big_file_id (:obj:`str`): File identifier of big (640x640) chat photo.
-
+            This file_id can be used only for photo download and only for as long as
+            the photo is not changed.
+        big_file_unique_id (:obj:`str`): Unique file identifier of big (640x640) chat photo,
+            which is supposed to be the same over time and for different bots.
+            Can't be used to download or reuse the file.
     Args:
-        small_file_id (:obj:`str`): File identifier of small (160x160) chat photo. This file_id can
-            be used only for photo download and only for as long as the photo is not changed.
-        big_file_id (:obj:`str`): File identifier of big (640x640) chat photo. This file_id can be
-            used only for photo download and only for as long as the photo is not changed.
+        small_file_id (:obj:`str`): Unique file identifier of small (160x160) chat photo. This
+            file_id can be used only for photo download and only for as long
+            as the photo is not changed.
+        small_file_unique_id (:obj:`str`): Unique file identifier of small (160x160) chat photo,
+            which is supposed to be the same over time and for different bots.
+            Can't be used to download or reuse the file.
+        big_file_id (:obj:`str`): Unique file identifier of big (640x640) chat photo. This file_id
+            can be used only for photo download and only for as long as the photo is not changed.
+        big_file_unique_id (:obj:`str`): Unique file identifier of big (640x640) chat photo,
+            which is supposed to be the same over time and for different bots.
+            Can't be used to download or reuse the file.
         bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     """
 
-    def __init__(self, small_file_id, big_file_id, bot=None, **kwargs):
+    def __init__(self,
+                 small_file_id,
+                 small_file_unique_id,
+                 big_file_id,
+                 big_file_unique_id,
+                 bot=None, **kwargs):
         self.small_file_id = small_file_id
+        self.small_file_unique_id = small_file_unique_id
         self.big_file_id = big_file_id
+        self.big_file_unique_id = big_file_unique_id
+
         self.bot = bot
 
-        self._id_attrs = (self.small_file_id, self.big_file_id)
+        self._id_attrs = (self.small_file_unique_id, self.big_file_unique_id,)
 
     @classmethod
     def de_json(cls, data, bot):
