@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2018
+# Copyright (C) 2015-2020
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -22,7 +22,6 @@ import os
 import socket
 import sys
 import warnings
-from builtins import str  # For PY2
 
 try:
     import ujson as json
@@ -37,9 +36,20 @@ try:
     from urllib3.util.timeout import Timeout
     from urllib3.fields import RequestField
 except ImportError:  # pragma: no cover
-    warnings.warn("python-telegram-bot wasn't properly installed. Please refer to README.rst on "
-                  "how to properly install.")
-    raise
+    try:
+        import urllib3
+        import urllib3.contrib.appengine as appengine
+        from urllib3.connection import HTTPConnection
+        from urllib3.util.timeout import Timeout
+        from urllib3.fields import RequestField
+        warnings.warn('python-telegram-bot is using upstream urllib3. This is allowed but not '
+                      'supported by python-telegram-bot maintainers.')
+    except ImportError:
+        warnings.warn(
+            "python-telegram-bot wasn't properly installed. Please refer to README.rst on "
+            "how to properly install.")
+        raise
+
 
 from telegram import (InputFile, TelegramError, InputMedia)
 from telegram.error import (Unauthorized, NetworkError, TimedOut, BadRequest, ChatMigrated,
@@ -50,11 +60,11 @@ def _render_part(self, name, value):
     """
     Monkey patch urllib3.urllib3.fields.RequestField to make it *not* support RFC2231 compliant
     Content-Disposition headers since telegram servers don't understand it. Instead just escape
-    \ and " and replace any \n and \r with a space.
+    \\ and " and replace any \n and \r with a space.
     """
     value = value.replace(u'\\', u'\\\\').replace(u'"', u'\\"')
     value = value.replace(u'\r', u' ').replace(u'\n', u' ')
-    return u'%s="%s"' % (name, value)
+    return u'{}="{}"'.format(name, value)
 
 
 RequestField._render_part = _render_part
@@ -64,7 +74,7 @@ logging.getLogger('urllib3').setLevel(logging.WARNING)
 USER_AGENT = 'Python Telegram Bot (https://github.com/python-telegram-bot/python-telegram-bot)'
 
 
-class Request(object):
+class Request:
     """
     Helper class for python-telegram-bot which provides methods to perform POST & GET towards
     telegram servers.
@@ -166,13 +176,9 @@ class Request(object):
 
         """
 
+        decoded_s = json_data.decode('utf-8', 'replace')
         try:
-            decoded_s = json_data.decode('utf-8')
             data = json.loads(decoded_s)
-        except UnicodeDecodeError:
-            logging.getLogger(__name__).debug(
-                'Logging raw invalid UTF-8 response:\n%r', json_data)
-            raise TelegramError('Server response could not be decoded using UTF-8')
         except ValueError:
             raise TelegramError('Invalid server response')
 
@@ -220,7 +226,7 @@ class Request(object):
         except urllib3.exceptions.HTTPError as error:
             # HTTPError must come last as its the base urllib3 exception class
             # TODO: do something smart here; for now just raise NetworkError
-            raise NetworkError('urllib3 HTTPError {0}'.format(error))
+            raise NetworkError('urllib3 HTTPError {}'.format(error))
 
         if 200 <= resp.status <= 299:
             # 200-299 range are HTTP success statuses
@@ -246,7 +252,7 @@ class Request(object):
         elif resp.status == 502:
             raise NetworkError('Bad Gateway')
         else:
-            raise NetworkError('{0} ({1})'.format(message, resp.status))
+            raise NetworkError('{} ({})'.format(message, resp.status))
 
     def get(self, url, timeout=None):
         """Request an URL.
@@ -274,7 +280,7 @@ class Request(object):
 
         Args:
             url (:obj:`str`): The web location we want to retrieve.
-            data (dict[str, str|int]): A dict of key/value pairs. Note: On py2.7 value is unicode.
+            data (dict[str, str|int]): A dict of key/value pairs.
             timeout (:obj:`int` | :obj:`float`): If this value is specified, use it as the read
                 timeout from the server (instead of the one specified during creation of the
                 connection pool).
